import requests
import json
from dnevnikmos.errors import *


class Homeworks:
    def __init__(self, user) -> None:
        self.session = user.session
        self.token = user.token
        self.id = user.id

    def get_homeworks_by_data(self, date):
        data = self.session.get(
            f"https://dnevnik.mos.ru/mobile/api/schedule?student_id={self.id}&date={date}",
            headers={
                "Authorization": self.token,
                "Auth-Token": self.token
            }
        ).json()
        homeworks = []
        # print(data)
        try:
            for activity in data["activities"]:
                if activity["type"] == "LESSON":
                    if activity["lesson"]["homework"] != '':
                        lesson_ = activity["lesson"]["subject_name"]
                        homework = activity["lesson"]["homework"]
                        homeworks.append(
                            {
                                "name": str(lesson_),
                                "homework": str(homework)
                            }
                        )
        except KeyError:
            raise DnevnikMosError("Неверная дата")
        return homeworks



from selenium import webdriver
from time import time, sleep
from urllib3.util import parse_url
from selenium.webdriver.common.by import By
from sys import exit



class UserToken:
    def get_token(login, password, executable_path):
        start_time = time()
        options = webdriver.ChromeOptions()
        options.add_argument("--disable-blink-features=AutomationControlled")
        driver = webdriver.Chrome(options=options, executable_path=executable_path)
        driver.get("https://school.mos.ru")
        sleep(3)
        login_button = driver.find_element(By.XPATH, '//*[@id="root"]/div[1]/div[1]/main/section/div/div[1]/div[3]/div/div[1]/div[2]/div')
        login_button.click()
        sleep(5)
        login_input = driver.find_element(By.ID, "login")
        login_input.send_keys(login)
        password_input = driver.find_element(By.ID, "password")
        password_input.send_keys(password)
        submit_button = driver.find_element(By.ID, "bind")
        submit_button.click()
        while "/?token" not in driver.current_url:
            pass
        try:
            callback_code = parse_url(driver.current_url).query[6:-17]
        except TypeError:
            driver.close()
            return "Возникла ошибка"

        driver.close()

        return callback_code



"""
DNEVNIK MOS LIB

version 0.1 beta

Work on Closed API DNEVNIK МЭШ (MOS)
"""

from dnevnikmos.marks import *
from dnevnikmos.homeworks import *
from dnevnikmos.school import *
from dnevnikmos.user import *
from dnevnikmos.user_token_getter import *



class Lessons:
    def __init__(self, user) -> None:
        self.data = user.data_about_user
    
    def get_lessons(self):
        return self.data_about_user["children"][0]["groups"]
    def get_sections(self):
        return self.data_about_user["children"][0]["sections"]


from dnevnikmos.errors import *


class Marks:
    def __init__(self, user) -> None:
        self.session = user.session
        self.token = user.token
        self.id = user.id

    def get_marks_by_data(self, date):
        data = self.session.get(
            f"https://dnevnik.mos.ru/mobile/api/schedule?student_id={self.id}&date={date}",
            headers={
                "Authorization": self.token,
                "Auth-Token": self.token
            }
        ).json()
        marks = []
        # print(data)
        try:
            for activity in data["activities"]:
                if activity["type"] == "LESSON":
                    if activity["lesson"]["marks"]:
                        lesson_ = activity["lesson"]["subject_name"]
                        mark = activity["lesson"]["marks"][0]["value"]
                        marks.append(
                            {"name": lesson_, "mark": mark}
                        )
        except KeyError:
            raise DnevnikMosError("Скорее всего, неверная дата")
        return marks

    def get_trimester_marks(self, trimester: int, academic_year_id: int = 10):
        """
        Триместр вводим в последовательности 0 - 1 триместр, 1 - 2 триместр, 2 - 3 триместр
        ID года вводим 10
        """
        data = self.session.get(
            f"https://dnevnik.mos.ru/reports/api/progress/json?academic_year_id={academic_year_id}&student_profile_id={self.id}",
            headers={
                "Authorization": self.token,
                "Auth-Token": self.token
            }
        ).json()
        marks = []
        for lesson in data:
            lesson_name = lesson["subject_name"]
            if lesson["periods"]:
                trimester_mark = lesson["periods"][0]["avg_five"]
            else:
                trimester_mark = "0"
            marks.append(
                {
                    "name": lesson_name,
                    "mark": trimester_mark
                }
            )
        return marks



class DnevnikMosError(Exception):
    def __init__(self, *args: object) -> None:
        if args:
            self.msg = args[0]
        else:
            self.msg = None
    def __str__(self) -> str:
        if self.msg:
            return "{}".format(self.msg)
        else:
            return "Error"


class School:
    def __init__(self, user) -> None:
        self.session = user.session
        self.token = user.token
        self.data_about_user = user.data_about_user
    def get_info_about_school(self):

        # print(data)
        return self.data_about_user["children"][0]["school"]


import setuptools

# Открытие README.md и присвоение его long_description.
with open("README.md", "r") as fh:
	long_description = fh.read()

# Определение requests как requirements для того, чтобы этот пакет работал. Зависимости проекта.
requirements = ["requests<=2.21.0", "selenium"]

# Функция, которая принимает несколько аргументов. Она присваивает эти значения пакету.
setuptools.setup(
	name="dnevnikmos",
	version="1.1",
	author="Boiko Arseniy",
	author_email="ars254642@gmail.com",
	description="Library for automated work with dnevnik.mos.ru",

	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://github.com/CyberBars1k/dnevnikmos/",
	packages=setuptools.find_packages(),
	classifiers=[
	],
	python_requires='>=3.6',
)



from requests import Session
from dnevnikmos.errors import DnevnikMosError


class User:
    def __init__(self, token=None) -> None:
        # Init function
        self.default_api_url = "https://dnevnik.mos.ru/mobile/api"
        self.token = token
        self.session = Session()
        self.data_about_user = self.login()

        if self.data_about_user[1] == 200:
            self.data_about_user = self.data_about_user[0]
            self.first_name = self.data_about_user["profile"]["first_name"]
            self.last_name = self.data_about_user["profile"]["last_name"]
            self.middle_name = self.data_about_user["profile"]["middle_name"]
            self.type = self.data_about_user["profile"]["type"]
            self.id = self.data_about_user["profile"]["id"]
            self.phone = self.data_about_user["profile"]["phone"]
            self.email = self.data_about_user["profile"]["email"]
            self.birth_date = self.data_about_user["children"][0]["birth_date"]
            self.sex = self.data_about_user["children"][0]["sex"]
            self.class_name = self.data_about_user["children"][0]["class_name"]
            self.contract_id = self.data_about_user["children"][0]["contract_id"]
            self.parents = self.data_about_user["children"][0]["representatives"]
        else:
            if self.data_about_user == 403:
                raise DnevnikMosError("non-existent token")
            elif self.data_about_user == 400:
                raise DnevnikMosError("Bad Request")
            elif self.data_about_user == 402:
                raise DnevnikMosError("Non-existent token")
            elif self.data_about_user == 401:
                raise DnevnikMosError("Your token expired")
            else:
                raise DnevnikMosError()


    def login(self):
        """
        Сюда ничего не задаем
        :return:
        """
        result = self.session.get(
            f"{self.default_api_url}/profile",
            headers={
                "Authorization": self.token,
                "Auth-Token": self.token
                })
        if result.status_code != 200:
            return [0, result.status_code]
        
        if result.json():
            return [result.json(), result.status_code]

    def get_date_in_format(self, year, month, day) -> str:
        """

        :param year:
        :param month:
        :param day:
        :return:
        """
        if len(str(day)) == 1:
            date ="0"+str(day)
        if len(str(month)) == 1:
            month ="0"+str(month)
        return f"{year}-{month}-{day}"

    def get_attendance_by_date(self, to_date, from_date):
        """
        :param to_date:
        :param from_date:
        :param contract_id:
        :return:
        """
        data = self.session.get(
            f"{self.default_api_url}/visits?from={from_date}&to={to_date}&contract_id={self.contract_id}",
            headers={
                "Authorization": self.token,
                "Auth-Token": self.token
            }
        )
        return data.json()["payload"]
    def get_notifications(self):
        """

        :return:
        """
        return self.session.get(
            f"{self.default_api_url}/notifications/search?student_id={self.id}",
            headers={
                "Authorization": self.token,
                "Auth-Token": self.token
            }
        ).json()
        
